-- Demo of investigating logging for SELECT-INTO

-- Create a database to play around with
CREATE DATABASE LoggingTest;
GO
USE LoggingTest;
GO

SET NOCOUNT ON;
GO
ALTER DATABASE LoggingTest SET AUTO_CREATE_STATISTICS OFF;
GO

-- Create a source table
CREATE TABLE SourceTable (
	c1	INT IDENTITY,
	c2	DATETIME DEFAULT GETDATE (),
	c3	CHAR (400) DEFAULT 'a');
GO
INSERT INTO SourceTable DEFAULT VALUES;
GO 100

-- Switch to FULL recovery model and flush the log
ALTER DATABASE LoggingTest SET RECOVERY FULL;
GO
CHECKPOINT;
GO

-- Do the SELECT-INSERT
BEGIN TRAN PaulsTran;
GO
SELECT * INTO DestTable FROM SourceTable;
GO

-- How much log was generated?
SELECT [database_transaction_log_bytes_used]
	FROM sys.dm_tran_database_transactions
WHERE [database_id] = DB_ID ('LoggingTest');
GO

-- Log amount: 49828

-- And what was the log?
SELECT * FROM fn_dblog (NULL, NULL);
GO

-- Commit the transaction
DROP TABLE DestTable;
GO
COMMIT TRAN;
GO

-- And now in BULK_LOGGED recovery model
ALTER DATABASE LoggingTest SET RECOVERY BULK_LOGGED;
GO
CHECKPOINT;
GO

-- Do the SELECT-INSERT
BEGIN TRAN PaulsTran;
GO
SELECT * INTO DestTable FROM SourceTable;
GO

-- How much log was generated?
SELECT [database_transaction_log_bytes_used]
	FROM sys.dm_tran_database_transactions
WHERE [database_id] = DB_ID ('LoggingTest');
GO

-- Log amount: 6072

-- And what was the log?
SELECT * FROM fn_dblog (NULL, NULL);
GO

-- Commit the transaction
DROP TABLE DestTable;
GO
COMMIT TRAN;
GO